Index: test/cctest/test-assembler-arm64.cc |
diff --git a/test/cctest/test-assembler-arm64.cc b/test/cctest/test-assembler-arm64.cc |
index 25f3adb502da94019ff3565101559016173d9311..1ce900b3f3e90b6a78727d1a64d4ea40867818df 100644 |
--- a/test/cctest/test-assembler-arm64.cc |
+++ b/test/cctest/test-assembler-arm64.cc |
@@ -8384,10 +8384,10 @@ static void PushPopJsspSimpleHelper(int reg_count, |
START(); |
// Registers x8 and x9 are used by the macro assembler for debug code (for |
// example in 'Pop'), so we can't use them here. We can't use jssp because it |
// will be the stack pointer for this test. |
- static RegList const allowed = ~(x8.Bit() | x9.Bit() | jssp.Bit()); |
+ static RegList const allowed = ~(ip0.Bit() | ip1.Bit() | jssp.Bit()); |
rmcilroy
2014/05/09 11:18:46
One last change required here - I think this is a
@@ -8384,10 +8384,10 @@ static void PushPopJsspSimpleHelper(int reg_count, |
START(); |
- // Registers x8 and x9 are used by the macro assembler for debug code (for |
+ // Registers ip0 and ip1 are used by the macro assembler for debug code (for |
// example in 'Pop'), so we can't use them here. We can't use jssp because it |
// will be the stack pointer for this test. |
jbramley
2014/05/09 11:23:51
We used x8/x9 _and_ ip0/ip1: ip0/ip1 were for gene
rmcilroy
2014/05/09 11:30:56
The reason this fails now without this change is b
|
if (reg_count == kPushPopJsspMaxRegCount) { |
reg_count = CountSetBits(allowed, kNumberOfRegisters); |
} |